## Crypto Dashboard

This example shows off a simple interactive Dashboard, which allows you to view
the balance of a cryptocurrency wallet, the details of a cryptocurrency, and a
chart of the price of a cryptocurrency.

## Lessons

In this example you can see how to:

-   Create a simple interactive dashboard
-   Pass data between components
-   Populate your application with your own data
-   Fetch data from an API or Local Storage

## Components

This template is composed of four main components:

1. `BalanceCard`: Displays the balance of a cryptocurrency wallet.
2. `CryptoCard`: Displays the details of a cryptocurrency.
3. `CryptoChart`: Displays a chart of the price of a cryptocurrency.
4. `DashboardPage`: Combines the `BalanceCard`, `CryptoCard`, and `CryptoChart`
   components and add some logic.
